@@ -35,8 +35,14 @@ function(x,labels=NULL,type="rectangle",cols="black", timeseries.as.labels = T,
 		for (i in 1:x$N) {
 
 			par(fig=c(0.35,1,offset+(i-1)/x$N*scale,offset+(i/x$N*scale)),mar=c(0,0,0,0),new=TRUE)
-			plot(X[,x$order[i]],ann=F,xaxt='n',yaxt="n",frame.plot=F,type="n")
-			lines(X[,x$order[i]],lw=2,col=cols[x$order[i] ])
+			if (x$multichannel) {
+				dat <- X[,x$order[i],1]
+			} else {
+				dat <- X[,x$order[i]]
+			}
+			 plot(dat,ann=F,xaxt='n',yaxt="n",frame.plot=F,type="n")
+			 lines(dat,lw=2,col=cols[x$order[i] ])
+
 			#text( 0, 0,  labels[i])
 			
 			
